@@ -63,23 +63,23 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.3_01'; # TRIAL VERSION
+our $VERSION = 'v0.4.3_02'; # TRIAL VERSION
 
-use Dist::Zilla::Tester::DieHard v0.5.0;    # Need `release` method.
+use Dist::Zilla::Tester::DieHard v0.6.0;    # `Survivor` should have `tempdir_obj` attribute.
 use File::Temp qw{ tempdir };
 use Test::DZil qw{ dist_ini };
 use Test::More;
 use Test::Routine;
 use Try::Tiny;
 
-# REQUIRE: Software::License::Perl_5
-# REQUIRE: Moose 2.0800
+## REQUIRE: Software::License::Perl_5
+## REQUIRE: Moose 2.0800
     # ^ Test will likely fail with older Moose.
     #   Starting from 2.0800 "Roles can now override methods from other roles…".
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =var $Cleanup
+#pod =variable $Cleanup
 #pod
 #pod C<Dist::Zilla::Tester> creates distribution source and build directories in a temporary directory,
 #pod and then unconditionally cleans it up. Sometimes (especially in case of test failure) such behavior
@@ -629,7 +629,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.3_01, released on 2016-12-19 22:05 UTC.
+Version v0.4.3_02, released on 2016-12-20 20:49 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
